-- AddOn : AT_Timer
-- Description : This Addon displays and manage a single timer control.
-- Author : Carter_DC
-- V 1.0.0
-- 
--
-- 
--Libraries--------------------------------------------------------------------
local LAM = LibStub("LibAddonMenu-2.0")


AT_Timer           = {}
AT_Timer.addonName = "AT_Timer"
AT_Timer.version   = "1.0.0"
AT_Timer.isOn      = false
AT_Timer.timerValue= 0
AT_Timer.defaults  = {  -- default settings for saved variables
     duration      = 60,
     beep          = true, 
     uiTop         = 33, 
     uiLeft        = 1250,
     fontColorR    = 1,
     fontColorG    = 0,
     fontColorB    = 0,
}
AT_Timer.savedVariables={}






-- Event handlers -------------------------------------------------------------

function AT_Timer.OnAddOnLoaded(eventCode, name)
   if name ~= AT_Timer.addonName then return end
   
   AT_Timer.savedVariables = ZO_SavedVars:New("ATTimerSavedVariables", 1, nil, AT_Timer.defaults)
   
   -- UI   
   AT_Timer.InitUI()
   -- Settings menu
   AT_Timer.CreateSettingsMenu()
   ZO_CreateStringId("SI_BINDING_NAME_AT_TIMER_START", "Start/Reset")
   
   --events
  
   EVENT_MANAGER:UnregisterForEvent(AT_Timer.addonName, EVENT_ADD_ON_LOADED)
end



function AT_Timer.StartReset()
  ATTimerUiLabel:SetText("0")
  ATTimerUiLabel:SetScale(1)
  ATTimerUiLabel:SetAnchor(TOP, ATTimerUi, TOP, 0, 0)
  
  if AT_Timer.isOn == true then 
    AT_Timer.timerValue = 0
   else
    AT_Timer.isOn= true
    AT_Timer.timerValue = 0
    ATTimerUi:SetHidden(false)
    AT_Timer.TimeLoop()
  end
end

function AT_Timer.TimeLoop()
  if AT_Timer.isOn == false then return end 
  AT_Timer.timerValue = AT_Timer.timerValue + 1
  
  if (AT_Timer.timerValue > AT_Timer.savedVariables.duration) then
    AT_Timer.isOn = false
    ATTimerUi:SetHidden(true)
    --[[if AT_Timer.savedVariables.beep == true then 
      PlaySound(SOUNDS.ABILITY_SLOTTED)--find a better sound ^^ 
    end]]--
  else
    if (AT_Timer.timerValue == 100) then
      ATTimerUiLabel:SetScale(0.9)
      ATTimerUiLabel:SetAnchor(TOP, ATTimerUi, TOP, 0, 2)
    end
    
    ATTimerUiLabel:SetText(tostring(AT_Timer.timerValue))
    zo_callLater(function() AT_Timer.TimeLoop() end, 1000)
  end
end


function AT_Timer.SetTimerDuration(sParam)
  local duration = tonumber(sParam)
  if (duration == nil) then return end
  duration = math.floor(duration+0.5)
  if (duration >180) or (duration <10) then return end
  AT_Timer.savedVariables.duration = duration
  CHAT_SYSTEM["containers"][1]["currentBuffer"]:AddMessage("Timer duration set to : "..duration.." sec") 
end

function AT_Timer.InitUI()

  ATTimerUi:SetHidden(not AT_Timer.isOn)
  AT_Timer.RestoreUIPosition()
  
  local texture = WINDOW_MANAGER:CreateControl("ATTimerUiTexture", ATTimerUi, CT_TEXTURE)
    texture:SetDimensions(50,50)
    texture:SetAnchor(CENTER, ATTimerUi, CENTER, 0, 12)
    texture:SetTexture("/esoui/art/actionbar/passiveabilityframe_round_up.dds")
    texture:SetDrawLevel(1)
  local label = WINDOW_MANAGER:CreateControl("ATTimerUiLabel", ATTimerUi, CT_LABEL)
    label:SetDimensions(50,50)
    label:SetVerticalAlignment(1)
    label:SetHorizontalAlignment(1)
    label:SetScale(1)
    label:SetAnchor(TOP, ATTimerUi, TOP, 0, 0)
    label:SetAlpha(1)
    label:SetFont("ZoFontWinH1")
    label:SetColor(AT_Timer.savedVariables.fontColorR,AT_Timer.savedVariables.fontColorG,AT_Timer.savedVariables.fontColorB,1)
    label:SetDrawLevel(2)  
 
 end




function AT_Timer.OnUIMoveStop()
  AT_Timer.savedVariables.uiTop = ATTimerUi:GetTop()
  AT_Timer.savedVariables.uiLeft = ATTimerUi:GetLeft()
end

function AT_Timer.RestoreUIPosition()
  local left = AT_Timer.savedVariables.uiLeft
  local top = AT_Timer.savedVariables.uiTop
 
  ATTimerUi:ClearAnchors()
  ATTimerUi:SetAnchor(TOPLEFT, GuiRoot, TOPLEFT, left, top)
end

-- Settings menu --------------------------------------------------------------
function AT_Timer.CreateSettingsMenu()
    
   local panelData = {
      type = "panel",
      name = AT_Timer.addonName,
      displayName = "|cFFAA33"..AT_Timer.addonName.."|r",
      author = "Carter_DC",
      version = AT_Timer.version,
      registerForRefresh = true,
      registerForDefaults = true,
   }
   LAM:RegisterAddonPanel(AT_Timer.addonName.."_LAM", panelData)

   local optionsTable = 
   {
      [1] = {
        type = "description",
        text = GetString(AT_TIMER_DESCRIPTION),
      },
      [2] = {
        type = "header",
        --name = "OPTIONS",
        width = "full",
      },
      [3] ={
         type = "slider",
         name = GetString(AT_TIMER_DURATION),
         tooltip = GetString(AT_TIMER_DURATION_TOOLTIP),
         min = 10,
         max = 180,
         step = 10,
         getFunc = function() return AT_Timer.savedVariables.duration end,
         setFunc = function(duration)
            AT_Timer.savedVariables.duration = duration    
         end,
         default = AT_Timer.defaults.duration,
      },
      [4] = {
        type = "colorpicker",
        name = GetString(AT_TIMER_FONTCOLOR),
        tooltip = GetString(AT_TIMER_FONTCOLOR_TOOLTIP),
        getFunc = function()
           return AT_Timer.savedVariables.fontColorR, AT_Timer.savedVariables.fontColorG, AT_Timer.savedVariables.fontColorB
              
        end,
        setFunc = function(r, g, b)
              ATTimerUiLabel:SetColor(r, g, b, 1)
              AT_Timer.savedVariables.fontColorR = r
              AT_Timer.savedVariables.fontColorG = g
              AT_Timer.savedVariables.fontColorB = b              
        end
      },
      
   }
   
   LAM:RegisterOptionControls(AT_Timer.addonName.."_LAM", optionsTable)
   
end


SLASH_COMMANDS["/timer"] = AT_Timer.SetTimerDuration
EVENT_MANAGER:RegisterForEvent(AT_Timer.addonName, EVENT_ADD_ON_LOADED, AT_Timer.OnAddOnLoaded)
